#!/bin/sh

net_model()
{
	device="$(readlink -f /sys/class/net/$1/device)" || return
	[ -z "${device##*pci*}" ] || return
	lspci -d $(cat $device/vendor):$(cat $device/device) | sed -n '
		s/^\S* //;
		s/Ethernet controller: //;
		s/(rev [^)]*)//;
		s/Advanced Micro Devices \[AMD\]/AMD/;
		s/Broadcom Corporation/Broadcom/;
		s/ATI Technologies Inc/ATI/;
		s/Silicon Integrated Systems \[SiS\]/SiS/;
		s/Hewlett-Packard Company/HP/;
		s/Sun Microsystems Computer Corp./Sun/;
		s/Realtek Semiconductor Co., Ltd./Realtek/;
		s/VIA Technologies, Inc./VIA/;
		1p; s/~/-/g'
}

iface_config()
{
	awk -v p_iface=$iface '
		function clear_c() { c_iface=""; c_mode=""; c_addr=""; c_mask=""; c_gw=""; }
		function print_c() {
			if (c_iface == p_iface) {
				print c_gw, c_mode;
			}
		}
		BEGIN {	OFS="~"; clear_c(); }
		$1 == "iface" {
			if (c_iface != "") { print_c(); clear_c(); }	
			c_iface = $2; c_mode = $4;
		}
		$1 == "address" { c_addr=$2; }
		$1 == "netmask" { c_mask=$2; }
		$1 == "gateway" { c_gw=$2; }
		END { print_c(); } ' /etc/network/interfaces	
}

for iface in `LANG=C ifconfig -a | sed -n 's/^\([^ ]*\) .*/\1/p'`; do
	echo -n "$iface~"
	echo -n "$(net_model $iface)~"
	HWADDR=$(LANG=C ifconfig $iface | sed -n 's/.* HWaddr \([0-9a-fA-F:-]*\).*/\1/p') #'
	IP=$(LANG=C ifconfig $iface | sed -n 's/.* inet addr:\s*\([0-9.]*\).*/\1/p') #'
	MASK=$(LANG=C ifconfig $iface | sed -n 's/.* Mask:\s*\([0-9.]*\).*/\1/p') #'
	echo -n "$HWADDR~$IP~$MASK~"
	
	echo -n "$(iface_config $iface)"
	echo
done

